@@ -261,6 +261,8 @@ backend_2(BACKEND *be, int s_listener, FILE *f_be, char *client_addr)
             fprintf(f_be, "%s: %s, chunked\r\n", h->hdr_name, h->hdr_value);
             logmsg(4, "%lX %s: %s, chunked %s:%d", pthread_self(), h->hdr_name, h->hdr_value, __FILE__, __LINE__);
             is_chunked = 1;
+        } if(!strcasecmp(h->hdr_name, "upgrade") || !strcasecmp(h->hdr_name, "upgrade-insecure-requests")) {
+            logmsg(4, "%lX %s: skipped %s:%d", pthread_self(), h->hdr_name, __FILE__, __LINE__);
         } else {
             fprintf(f_be, "%s: %s\r\n", h->hdr_name, h->hdr_value);
             logmsg(4, "%lX %s: %s %s:%d", pthread_self(), h->hdr_name, h->hdr_value, __FILE__, __LINE__);
@@ -352,8 +354,10 @@ backend_2(BACKEND *be, int s_listener, FILE *f_be, char *client_addr)
         }
         cp = strtok_r(buf, ":", &tp);
         if(!strcasecmp(cp, "connection") || !strcasecmp(cp, "keep-alive") || !strcasecmp(cp, "proxy-connection") || !strcasecmp(cp, "transfer-encoding")
-        || !strcasecmp(cp, "te") || !strcasecmp(cp, "content-length") || !strcasecmp(cp, "upgrade"))
+        || !strcasecmp(cp, "te") || !strcasecmp(cp, "content-length") || !strcasecmp(cp, "upgrade")) {
+            logmsg(4, "%lX header %s skipped %s:%d", pthread_self(), buf, __FILE__, __LINE__);
             continue;
+        }
         if((ttp = strtok_r(NULL, "\r", &tp)) != NULL)
             while(*ttp == ' ')
                 ttp++;
@@ -435,45 +439,6 @@ backend_2(BACKEND *be, int s_listener, FILE *f_be, char *client_addr)
     nn_send(s_listener, "", 0, 0);
     logmsg(4, "%lX sent end-of-content %s:%d", pthread_self(), __FILE__, __LINE__);
 
-    r_headers = hpack_headerblock_new();
-    while(fgets(buf, MAXBUF, f_be) != NULL) {
-        if(buf[0] == '\r' || buf[0] == '\n')
-            break;
-        logmsg(4, "%lX have trailer %s %s:%d", pthread_self(), buf, __FILE__, __LINE__);
-        cp = strtok_r(buf, ":", &tp);
-        if(!strcasecmp(cp, "connection") || !strcasecmp(cp, "keep-alive") || !strcasecmp(cp, "proxy-connection") || !strcasecmp(cp, "transfer-encoding")
-        || !strcasecmp(cp, "te") || !strcasecmp(cp, "content-length") || !strcasecmp(cp, "upgrade"))
-            continue;
-        if((ttp = strtok_r(NULL, "\r", &tp)) != NULL)
-            while(*ttp == ' ')
-                ttp++;
-        else
-            ttp = "";
-        hpack_header_add(r_headers, cp, ttp, HPACK_INDEX);
-        logmsg(4, "%lX trailer %s => %s: %s %s:%d", pthread_self(), buf, cp, ttp, __FILE__, __LINE__);
-        total += strlen(cp) + strlen(ttp);
-    }
-    if((content = hpack_encode(r_headers, &h_len, tab)) == NULL) {
-        logmsg(4, "%lX failed encode %s:%d", pthread_self(), __FILE__, __LINE__);
-        hpack_headerblock_free(r_headers);
-        hpack_table_free(tab);
-        close(fileno(f_be));
-        fclose(f_be);
-        EOF_LISTENER(s_listener);
-        return -1;
-    }
-    for(n = 0; h_len > 0; ) {
-        nn_send(s_listener, content + n, h_len > FRAMESIZE? FRAMESIZE: h_len, 0);
-        n += (h_len > FRAMESIZE? FRAMESIZE: h_len);
-        h_len -= (h_len > FRAMESIZE? FRAMESIZE: h_len);
-    }
-    free(content);
-    hpack_headerblock_free(r_headers);
-    hpack_table_free(tab);    
-    /* end of trailers */
-    nn_send(s_listener, "", 0, 0);
-    logmsg(4, "%lX sent end-of-trailers %s:%d", pthread_self(), __FILE__, __LINE__);
-
     EOF_LISTENER(s_listener);
     time_stamp(buf);
     logmsg(0, "%s - - [%s] \"%s\" %d %ld", client_addr, buf, request, reply_code, total);
