@@ -367,7 +367,7 @@ get_one(char *filename)
     mbedtls_x509_name   *nd;
     mbedtls_asn1_buf    data;
     mbedtls_x509_sequence   *san;
-    regex_t     one_host;
+    regex_t     *one_host;
     UT_array    *hosts;
     UT_icd      regex_icd = {sizeof(regex_t), NULL, NULL, NULL};
     char        buf[NI_MAXHOST];
@@ -397,13 +397,18 @@ get_one(char *filename)
                         buf[j++] = '.';
                         buf[j++] = ']';
                         buf[j++] = '+';
+                    } else if(data.p[i] == '.') {
+                        buf[j++] = '\\';
+                        buf[j++] = '.';
                     } else
                         buf[j++] = data.p[i];
                 buf[j] = '\0';
                 logmsg(4, "get_one add pattern %s %s:%d", buf, __FILE__, __LINE__);
-                if(regcomp(&one_host, buf, REG_ICASE | REG_EXTENDED))
+                if((one_host = (regex_t *)malloc(sizeof(regex_t))) == NULL)
+                    fatal("Can't alloc regex for %s",buf);
+                if(regcomp(one_host, buf, REG_ICASE | REG_EXTENDED))
                     fatal("Certificate in %s: bad host name pattern %s",filename, buf);
-                utarray_push_back(hosts, &one_host);
+                utarray_push_back(hosts, one_host);
             }
 
         for(san = &cur->subject_alt_names; san != NULL; san = san->next)
@@ -418,13 +423,18 @@ get_one(char *filename)
                         buf[j++] = '.';
                         buf[j++] = ']';
                         buf[j++] = '+';
+                    } else if(data.p[i] == '.') {
+                        buf[j++] = '\\';
+                        buf[j++] = '.';
                     } else
                         buf[j++] = data.p[i];
                 buf[j] = '\0';
                 logmsg(4, "get_one add pattern %s %s:%d", buf, __FILE__, __LINE__);
-                if(regcomp(&one_host, buf, REG_ICASE | REG_EXTENDED))
-                    fatal("Certificate in %s: bad host alt name pattern %s",filename, buf);
-                utarray_push_back(hosts, &one_host);
+                if((one_host = (regex_t *)malloc(sizeof(regex_t))) == NULL)
+                    fatal("Can't alloc regex for %s",buf);
+                if(regcomp(one_host, buf, REG_ICASE | REG_EXTENDED))
+                    fatal("Certificate in %s: bad host name pattern %s",filename, buf);
+                utarray_push_back(hosts, one_host);
             }
         if((res->host = calloc(utarray_len(hosts), sizeof(regex_t))) == NULL)
             fatal("SNI: out of memory");
@@ -544,7 +554,7 @@ get_https(yaml_document_t *document, yaml_node_t *root)
             mbedtls_ssl_conf_ciphersuites(res.conf, ciphers);
         if(res.sni == NULL)
             fatal("HTTPSListener at %ld: no certificates defined", vals->start_mark.line);
-        mbedtls_ssl_conf_sni(res.conf, do_sni, &res.sni);
+        mbedtls_ssl_conf_sni(res.conf, do_sni, res.sni);
         mbedtls_ssl_conf_own_cert(res.conf, &res.sni[0]->certificate, &res.sni[0]->key);
         if(res.sni[0]->certificate.next != NULL)
             mbedtls_ssl_conf_ca_chain(res.conf, res.sni[0]->certificate.next, NULL );
