@@ -69,7 +69,7 @@ static size_t	 hbuf_left(struct hbuf *);
 
 static struct hpack	 hpack_global;
 
-#ifdef  __gnu_linux__
+#ifdef  __GLIBC__
 /* these functions are available on BSD, but not on Linux */
 
 #include    <stdlib.h>
@@ -375,7 +375,6 @@ hpack_decode(unsigned char *data, size_t len, struct hpack_table *hpack)
 	int				 ret = -1;
 
 	if (len == 0 || len > LONG_MAX)
-		goto fail;
 
 	if (hpack == NULL && (hpack = ctx = hpack_table_new(0)) == NULL)
 		goto fail;
